
*****************************************************************
*****************************************************************
*Title    : Winning the Peace Locally                           *
*Journal  : Interntional Organization  							*
*Authors  : Andrea Ruggeri, Han Dorussen and Ismene T. Gizelis	*
*Date     : 22 May 2016											*
*Machine  : AR MacBook											*
*Locations: Amsterdam, Essex, Oxford, Savona					*
*****************************************************************
*****************************************************************



*************************************************************************************************
*List Tables and Figures										
*
*Figure 1 : Map 
*Figure 2 : Box Plots
*Figure 3 : Graph Effects PKO Size Onset
*Figure 4 : Graph Effects PKO Size Duration
*Figure 5 : Graph Effects Spatial lags
*
*Table 1: L1 matched data VS unmatched data
*Table 2: Matched Data & Logit Regressions - onset and Duration
*Table 3: Biviariate Autoregressive
*Table 4: Matched Data & Logit Regressions - onset and Duration -UN Size
*Table 5: Spatila Lags Matched Data & Logit Regressions - onset and Duration -UN Size
*
************************************************************************************************



************************************************************************************************************
*Change Directory
************************************************************************************************************

cd "RDG_IO_replication"


************************************************************************************************************
*FIGURE 1:  Map --> done with ARCgis
************************************************************************************************************

************************************************************************************************************
*TABLE 1 : L1 Distances Unmatched and matched
************************************************************************************************************
use "matchingdata.dta",clear
imb avgttime avgadjimr popgpw2000_40 avgmnt  borddist capdist prec_new , treatment(PKO)
cem avgttime avgadjimr popgpw2000_40 avgmnt  borddist capdist prec_new , treatment(PKO)

************************************************************************************************************
*FIGURE 2:  Examples Matched Variables --> *Distribution Variables before and after Matching
************************************************************************************************************
label define PKO 0 "noPKO" 1 "yesPKO"
gen  MATCH=0
replace MATCH=1 if cem_matched==1
label define MATCH 0 "Unbalanced" 1 "Balanced"
graph box avgttime , inten(0)   medtype(line) over(PKO, relabel(1 "No PKO" 2 "PKO")) over( MATCH, relabel(1 "Non-matched" 2 "Matched") )   ytitle("") subtitle("Average Travelling Time") title("Before and After Matching") scheme(s1mono)
graph box popgpw2000_40 , inten(0)    medtype(line)  over(PKO, relabel(1 "No PKO" 2 "PKO")) over( MATCH, relabel(1 "Non-matched" 2 "Matched") )   ytitle("") subtitle("Population") title("Before and After Matching") scheme(s1mono)


************************************************************************************************************
*TABLE 2 : Logit Onset and Duration with Matched Data
************************************************************************************************************
*ONSET, MODEL 1
 use "model1.dta", clear
logit conflict  PKO borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new PEACEyrs* [iweight=cem_weights]   if  lag1conflict==0, robust 
est store m1
estout m1 , cells(b (star fmt(3)) se)  stats(alpha bic N chi2)  style(fixed)
est clear
*DURATION, MODEL 2
use "model2.dta", clear
logit conflict  PKO borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new CONFyrs* [iweight=cem_weights]   if   lag1conflict==1, robust
est store m2
estout m2 , cells(b (star fmt(3)) se)  stats(alpha bic N chi2)  style(fixed)
est clear




************************************************************************************************************
*TABLE 3: Recursive Bivariate Probit & Unmatched 
************************************************************************************************************
est clear
*ONSET , MODEL 3
use "model3.dta", clear
biprobit  ( PKO= borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new PEACEyrs*) (conflict  PKO borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new PEACEyrs*)  if  lag1conflict==0 , robust
est store m3
estout m3 , cells(b (star fmt(3)) se)  stats(alpha bic N chi2)  style(fixed)
est clear 
*DURATION , MODEL 4
use "model4.dta", clear
biprobit  ( PKO= borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new CONFyrs*) (conflict  PKO borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new CONFyrs*)  if  lag1conflict==1 , robust
est store m4
estout m4 , cells(b (star fmt(3)) se)  stats(alpha bic N chi2)  style(fixed)
est clear
*DURATION , MODEL 5 with interaction
use "model5.dta", clear
estimates clear
biprobit  ( PKO=  c.borddist##c.AFRressupply  capdist  avgttime avgadjimr popgpw2000_40 avgmnt prec_new  CONFyrs*) (conflict  PKO  borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new CONFyrs*)  if  lag1conflict==1 , robust
estimates store m5
estout m5 , cells(b (star fmt(3)) se)  stats(alpha bic N chi2)  style(fixed)
  

  
************************************************************************************************************
*TABLE 4 : PKO Size.  with Matched Data
************************************************************************************************************
*ONSET,  MODEL 6
use "model6.dta", clear
est clear
logit conflict  logUNstrenght  borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new PEACEyrs* [iweight=cem_weights]   if lag1conflict==0, robust
est store m6
estout m6 , cells(b (star fmt(3)) se)  stats(alpha bic N chi2)  style(fixed)
*DURATION, MODEL 7
use "model7.dta", clear
logit conflict  logUNstrenght  borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new CONFyrs* [iweight=cem_weights]   if  lag1conflict==1, robust
est store m7
estout m7 , cells(b (star fmt(3)) se)  stats(alpha bic N chi2)  style(fixed)
  est clear


************************************************************************************************************
*Figure 3 : Graph Effects PKO Size Onset 
************************************************************************************************************
use "model6.dta", clear
logit conflict  logUNstrenght  borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new PEACEyrs* [iweight=cem_weights]   if  lag1conflict==0, robust
margins,  vce(unconditional) at(logUNstrenght=(0 (0.25)8.7 ))
marginsplot ,  recast(line) recastci(rline) scheme(s1mono) title(" ") ///
ytitle("Probability Onset in Grid Year") xtitle("(log) Number UN Peacekeepers in Grid Year") 
*Note in article we have plotted same simulation but with exp(logPKOsize)

************************************************************************************************************
*Figure  4 : Graph Effects PKO Size Duration
************************************************************************************************************
use "model7.dta", clear
logit conflict  logUNstrenght  borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new CONFyrs* [iweight=cem_weights]   if lag1conflict==1, robust
margins,  vce(unconditional) at(logUNstrenght=(0 (0.25)8.7 ))
marginsplot ,  recast(line) recastci(rline) scheme(s1mono) title(" ") ///
ytitle("Probability Duration in Grid Year") xtitle("(log) Number UN Peacekeepers in Grid Year") 
*Note in article we have plotted same simulation but with exp(logPKOsize)

 
************************************************************************************************************
*Figure 5  : Graph Effects Spatial Lags
************************************************************************************************************ 
use "figuresplags.dta",clear
* Onset & SpLag PKO presence 
logit conflict  PKO spLag_PKOt_1 borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new PEACEyrs* [iweight=cem_weights]   if  lag1conflict==0, robust
margins ,  vce(unconditional) at(spLag_PKOt_1=(0 (0.1)1 )) atmeans
marginsplot ,  recast(line) recastci(rline) ci1opts(lp(-) lc(black)) scheme(s1mono) title(" ") ytitle("Pr(Onset Conflict)") xtitle("Spatial Lag PKO presence at t-1")
graph save Graph "/Users/andrearuggeri/Desktop/IOjuly2015rep/gr1.gph", replace
*Duration & SpLag PKO presence 
logit conflict  PKO spLag_PKOt_1 borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new CONFyrs* [iweight=cem_weights]   if lag1conflict==1, robust
margins ,  vce(unconditional) at(spLag_PKOt_1=(0 (0.1)1 )) atmeans
marginsplot ,  recast(line) recastci(rline) scheme(s1mono) title(" ") ci1opts(lp(-) lc(black)) ytitle("Pr(Duration Conflict)") xtitle("Spatial Lag PKO presence at t-1")
graph save Graph "/Users/andrearuggeri/Desktop/IOjuly2015rep/gr2.gph", replace
* Onset & SpLag PKO size
logit conflict  logUNstrenght  spLag_UNstrenghtt_1 borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new PEACEyrs* [iweight=cem_weights]   if lag1conflict==0, robust
margins ,  vce(unconditional) at(spLag_UNstrenghtt_1=(0 (0.5)8 )) atmeans
marginsplot ,  recast(line) recastci(rline) ci1opts(lp(-) lc(black)) scheme(s1mono) title(" ") ytitle("") xtitle("Spatial Lag PKO size at t-1")
graph save Graph "/Users/andrearuggeri/Desktop/IOjuly2015rep/gr3.gph", replace
*Duration & SpLag PKO size
logit conflict  logUNstrenght  spLag_UNstrenghtt_1 borddist capdist avgttime avgadjimr popgpw2000_40 avgmnt prec_new CONFyrs* [iweight=cem_weights]   if  lag1conflict==1, robust
margins ,  vce(unconditional) at(spLag_UNstrenghtt_1=(0 (0.5)8 )) atmeans
marginsplot ,  recast(line) recastci(rline) ci1opts(lp(-) lc(black)) scheme(s1mono) title(" ") ytitle("") xtitle("Spatial Lag PKO size at t-1")
graph save Graph "/Users/andrearuggeri/Desktop/IOjuly2015rep/gr4.gph", replace
graph combine gr1.gph gr3.gph gr2.gph gr4.gph, scheme(s1mono)


